diff --git a/src/backend/access/gist/gistxlog.c b/src/backend/access/gist/gistxlog.c
index 9a86fb3fef..8e9afaff30 100644
--- a/src/backend/access/gist/gistxlog.c
+++ b/src/backend/access/gist/gistxlog.c
@@ -580,7 +580,7 @@ gistXLogAssignLSN(void)
 	int			dummy = 0;
 
 	/*
-	 * Records other than SWITCH_WAL must have content. We use an integer 0 to
+	 * Records other than XLOG_SWITCH must have content. We use an integer 0 to
 	 * follow the restriction.
 	 */
 	XLogBeginInsert();
diff --git a/src/backend/access/transam/xlogreader.c b/src/backend/access/transam/xlogreader.c
index cadea21b37..133b09dd69 100644
--- a/src/backend/access/transam/xlogreader.c
+++ b/src/backend/access/transam/xlogreader.c
@@ -1513,7 +1513,7 @@ WALRead(XLogReaderState *state,
 		/*
 		 * If the data we want is not in a segment we have open, close what we
 		 * have (if anything) and open the next one, using the caller's
-		 * provided openSegment callback.
+		 * provided segment_open callback.
 		 */
 		if (state->seg.ws_file < 0 ||
 			!XLByteInSeg(recptr, state->seg.ws_segno, state->segcxt.ws_segsize) ||
diff --git a/src/backend/commands/tablecmds.c b/src/backend/commands/tablecmds.c
index 6536cf2418..c7a8a689b7 100644
--- a/src/backend/commands/tablecmds.c
+++ b/src/backend/commands/tablecmds.c
@@ -2984,7 +2984,7 @@ MergeAttributes(List *schema, List *supers, char relpersistence,
 				 * generated column, we'll take its generation expression in
 				 * preference to the parent's.  We must check that the child
 				 * column doesn't specify a default value or identity, which
-				 * matches the rules for a single column in parse_util.c.
+				 * matches the rules for a single column in parse_utilcmd.c.
 				 *
 				 * Conversely, if the parent column is not generated, the
 				 * child column can't be either.  (We used to allow that, but
diff --git a/src/backend/executor/nodeAgg.c b/src/backend/executor/nodeAgg.c
index 3aab5a0e80..e71911aa46 100644
--- a/src/backend/executor/nodeAgg.c
+++ b/src/backend/executor/nodeAgg.c
@@ -3006,7 +3006,7 @@ hashagg_batch_new(LogicalTape *input_tape, int setno,
 }
 
 /*
- * read_spilled_tuple
+ * hashagg_batch_read
  * 		read the next tuple from a batch's tape.  Return NULL if no more.
  */
 static MinimalTuple
diff --git a/src/backend/partitioning/partbounds.c b/src/backend/partitioning/partbounds.c
index cf1156b842..c685621416 100644
--- a/src/backend/partitioning/partbounds.c
+++ b/src/backend/partitioning/partbounds.c
@@ -2340,7 +2340,7 @@ merge_default_partitions(PartitionMap *outer_map,
 		/*
 		 * The default partitions have to be joined with each other, so merge
 		 * them.  Note that each of the default partitions isn't merged yet
-		 * (see, process_outer_partition()/process_innerer_partition()), so
+		 * (see, process_outer_partition()/process_inner_partition()), so
 		 * they should be merged successfully.  The merged partition will act
 		 * as the default partition of the join relation.
 		 */
diff --git a/src/include/access/toast_helper.h b/src/include/access/toast_helper.h
index 96d8e5a685..e971bd2c8e 100644
--- a/src/include/access/toast_helper.h
+++ b/src/include/access/toast_helper.h
@@ -43,7 +43,7 @@ typedef struct
 	/*
 	 * Before calling toast_tuple_init, the caller must initialize the
 	 * following fields.  Each array must have a length equal to
-	 * ttc_rel->rd_att->natts.  The tts_oldvalues and tts_oldisnull fields
+	 * ttc_rel->rd_att->natts.  The ttc_oldvalues and ttc_oldisnull fields
 	 * should be NULL in the case of an insert.
 	 */
 	Relation	ttc_rel;		/* the relation that contains the tuple */
@@ -53,9 +53,9 @@ typedef struct
 	bool	   *ttc_oldisnull;	/* null flags from previous tuple */
 
 	/*
-	 * Before calling toast_tuple_init, the caller should set tts_attr to
+	 * Before calling toast_tuple_init, the caller should set ttc_attr to
 	 * point to an array of ToastAttrInfo structures of a length equal to
-	 * tts_rel->rd_att->natts.  The contents of the array need not be
+	 * ttc_rel->rd_att->natts.  The contents of the array need not be
 	 * initialized.  ttc_flags also does not need to be initialized.
 	 */
 	uint8		ttc_flags;
diff --git a/src/include/nodes/nodeFuncs.h b/src/include/nodes/nodeFuncs.h
index e63b399b8d..20921b45b9 100644
--- a/src/include/nodes/nodeFuncs.h
+++ b/src/include/nodes/nodeFuncs.h
@@ -29,7 +29,7 @@ struct PlanState;				/* avoid including execnodes.h too */
 #define QTW_EXAMINE_RTES_AFTER		0x20	/* examine RTE nodes after their
 											 * contents */
 #define QTW_DONT_COPY_QUERY			0x40	/* do not copy top Query */
-#define QTW_EXAMINE_SORTGROUP		0x80	/* include SortGroupNode lists */
+#define QTW_EXAMINE_SORTGROUP		0x80	/* include SortGroupClause lists */
 
 /* callback function for check_functions_in_node */
 typedef bool (*check_function_callback) (Oid func_id, void *context);
